@@ -389,7 +389,7 @@ bool GParted_Core::snap_to_cylinder( const Device & device, Partition & partitio
 		if ( partition .get_length() < partition .sectors_used )
 		{
 			error = String::ucompose( 
-				_("A partition with used sectors (%1) greater than it's length (%2) is not valid"),
+				_("A partition with used sectors (%1) greater than its length (%2) is not valid"),
 				partition .sectors_used,
 				partition .get_length() ) ;
 			return false ;
@@ -660,19 +660,21 @@ void GParted_Core::read_mountpoints_from_file(
 			mountpoint = Utils::regexp_label( line, "^/[^ \t]+[ \t]+([^ \t]+)" ) ;
 			if ( mountpoint .length() > 0 && node .length() > 0 )
 			{
-				//If node is a symbolic link (e.g., /dev/root), then find real path
-				if ( file_test( node, Glib::FILE_TEST_IS_SYMLINK ) )
-				{
-					char c_str[4096+1] ;
-					Glib::ustring tmp_node = node ;
-					//FIXME: it seems realpath is very unsafe to use (manpage)...
-					realpath( tmp_node .c_str(), c_str ) ;
-					if ( tmp_node .length() > 0 )
-						node = tmp_node ;
-				}
-				//only add this path if it exists
+				//Only add node path(s) if mount point exists
 				if ( file_test( mountpoint, Glib::FILE_TEST_EXISTS ) )
+				{
 					map[ node ] .push_back( mountpoint ) ;
+
+					//If node is a symbolic link (e.g., /dev/root)
+					//  then find real path and add entry
+					if ( file_test( node, Glib::FILE_TEST_IS_SYMLINK ) )
+					{
+						char c_str[4096+1] ;
+						//FIXME: it seems realpath is very unsafe to use (manpage)...
+						if ( realpath( node .c_str(), c_str ) != NULL )
+							map[ c_str ] .push_back( mountpoint ) ;
+					}
+				}
 			}
 		}
 
@@ -1555,7 +1557,7 @@ bool GParted_Core::move_filesystem( const Partition & partition_old,
 	{
 		operationdetail .add_child( OperationDetail( _("move file system") ) ) ;
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("new and old file system have the same position -- skipping this operation"),
+			OperationDetail( _("new and old file system have the same position.  Hence skipping this operation"),
 					 STATUS_NONE,
 					 FONT_ITALIC ) ) ;
 
@@ -1760,7 +1762,7 @@ bool GParted_Core::resize_move_partition( const Partition & partition_old,
 	if ( action == NONE )
 	{
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("new and old partition have the same size and position -- skipping this operation"),
+			OperationDetail( _("new and old partition have the same size and position.  Hence skipping this operation"),
 					  STATUS_NONE,
 					  FONT_ITALIC ) ) ;
 
@@ -1879,7 +1881,7 @@ bool GParted_Core::resize_filesystem( const Partition & partition_old,
 			operationdetail .add_child( OperationDetail( _("resize file system") ) ) ;
 			operationdetail .get_last_child() .add_child( 
 				OperationDetail( 
-					_("new and old file system have the same size -- skipping this operation"),
+					_("new and old file system have the same size.  Hence skipping this operation"),
 					STATUS_NONE,
 					FONT_ITALIC ) ) ;
 		
@@ -2129,7 +2131,7 @@ void GParted_Core::rollback_transaction( const Partition & partition_src,
 {
 	if ( total_done > 0 )
 	{
-		operationdetail .add_child( OperationDetail( _("rollback last transaction") ) ) ;
+		operationdetail .add_child( OperationDetail( _("roll back last transaction") ) ) ;
 
 		//find out exactly which part of the file system was copied (and to where it was copied)..
 		Partition temp_src = partition_src ;
@@ -2661,7 +2663,7 @@ bool GParted_Core::update_bootsector( const Partition & partition, OperationDeta
 			succes = false ;
 			error_message += "\n" ;
 			/*TO TRANSLATORS: looks like Failed to set the number of hidden sectors to 05ab4f00 in the ntfs boot record. */
-			error_message += String::ucompose( _("Failed to set the number of hidden sectors to %1 in the ntfs boot record."), reversed_hex ) ;
+			error_message += String::ucompose( _("Failed to set the number of hidden sectors to %1 in the NTFS boot record."), reversed_hex ) ;
 			error_message += "\n" ;
 			error_message += String::ucompose( _("You might try the following command to correct the problem:"), reversed_hex ) ;
 			error_message += "\n" ;
